import os

c="sxbutils"

def do_stuff():
    m=c+".do_stuff"
    print ("Manchester United")

def validate_envvars(envvars):

    m=c+".validate_envvars"
    print(m+" Starts")

    count=0
    try:
       for envvar in envvars:
          count += 1
          print(m+" "+envvar.name)
          if not envvar.name in os.environ and envvar.required:
              message=m+" missing envvar ("+envvar.name+") and it is required"
              raise Exception(message)

    except Exception as e:
       message=m+" An exception occurred, error="+str(e)+""
       raise Exception(message)

    finally:
       print(m+" Finally")

    print(m+" validated "+str(count)+" envvars")




class envvar:
    def __init__(self, name, required, example):
        self.name=name
        self.required=required
        self.example=example

    def tostr(self):
        tostr="name="+self.name+" required="+str(self.required)+" example="+self.example
        print("name="+self.name)
        print("required="+str(self.required))
        print("example="+self.example)
        return tostr




import sxbutils
from envvar import envvar 

def test_stub():
    try:
        m="test_stub"
        sxbutils.do_stuff()
        report=envvar("REPORT", True, "sxb.txt")
        diddle=envvar("DIDDLE", False, "did")

        envvars=[]
        envvars.append(report)
        envvars.append(diddle)
        print(m+" report.tostr()="+report.tostr())

# External lib
        sxbutils.validate_envvars(envvars)

    except Exception as e:
       print(m+" An exception occurred, error="+str(e)+"")

    finally:
       print(m+" Finally")

def test2():
    m="test2"
    #print(sxbutils.__version__)


test_stub()
test2()
